@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool-II/recovery.c,v 1.18.2.1 2011/02/23 13:19:32 kitagawa Exp $
+ * $Header$
  *
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
@@ -71,8 +71,7 @@ int start_recovery(int recovery_node)
 	conn = connect_backend_libpq(backend);
 	if (conn == NULL)
 	{
-		PQfinish(conn);
-		pool_error("start_recover: could not connect master node.");
+		pool_error("start_recovery: could not connect master node (%d)", node_id);
 		return 1;
 	}
 
